@@ -100,7 +100,7 @@ static char *models[] =
 	"AMD Athlon(tm) 64 Processor 3700+", "x86_64",
 	"AMD Athlon(tm) 64 X2 Dual Core Processor 5400+", "x86_64",
 	"AMD Phenom(tm) II X6 1055T Processor", "Phenom II",
-	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "AMD A6-6310 with Radeon R4",
+	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "A6-6310 with Radeon R4",
         "Am5x86", "5x86",
         "C6", "C6",
 	"C6-2", "C6-2",
@@ -140,9 +140,12 @@ static char *models[] =
 	"Intel(R) Celeron(R) M processor         1.40GHz", "Celeron M",
 	"Mobile Intel(R) Pentium(R) 4     CPU 3.06GHz", "Pentium-M 4",
 	"Intel(R) Core(TM) Solo CPU     U1400  @ 1.20GHz", "Core Solo",
+	"Intel(R) Core(TM) i7-4600M CPU @ 2.90GHz", "Core i7",
 	"Intel(R) Core(TM)2 CPU          6600  @ 2.40GHz", "Core 2",
 	"Intel(R) Core(TM)2 Duo CPU     P8600  @ 2.40GHz", "Core 2 Duo",
+	"Intel(R) Core(TM)2 Duo CPU     E7400  @ 2.80GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     E8400  @ 3.00GHz", "Core 2 Duo",
+	"Intel(R) Core(TM)2 Quad CPU    Q9550  @ 2.83GHz", "Core 2 Quad",
 	"Genuine Intel(R) CPU            2140  @ 1.60GHz", "Pentium 4",
         NULL, NULL
 };
